@@ -164,7 +164,8 @@ class BluexpressHandler:
         """
         parse = xmltodict.parse(raw_data.get('tracking_data'))
         json_data = json.loads(json.dumps(parse))
-        documento = json_data['soap:Envelope']['soap:Body']['ns3:responseObtenerDocumento']['listaDocumento']['documento']
+        list_keys = list(json_data['soap:Envelope']['soap:Body'].keys())
+        documento = json_data['soap:Envelope']['soap:Body'][list_keys[0]]['listaDocumento']['documento']
         pinchazos = documento['listaPinchazosNacionales']['pinchazo']
 
         events = [
@@ -191,7 +192,8 @@ class BluexpressHandler:
         """
         parse = xmltodict.parse(raw_data.get('tracking_data'))
         json_data = json.loads(json.dumps(parse))
-        documento = json_data['soap:Envelope']['soap:Body']['ns3:responseObtenerDocumento']['listaDocumento']['documento']
+        list_keys = list(json_data['soap:Envelope']['soap:Body'].keys())
+        documento = json_data['soap:Envelope']['soap:Body'][list_keys[0]]['listaDocumento']['documento']
         macroestados = documento['listaMacroestados']['macroestado']
         status = macroestados[-1]['nombre']
         is_delivered = False
